import { MapContainer, TileLayer, Marker, Popup, useMapEvents } from 'react-leaflet';
import 'leaflet/dist/leaflet.css';
import React, { useState } from 'react';

const Map = () => {
    const position = [63, 16]; // the position on the map which should be shown in the center of the screen 

    const [marker1, setMarker1] = useState(null);
    const [marker2, setMarker2] = useState(null);
    const [current, setCurrent] = useState(1);


    function LocationMarker() {
        useMapEvents({
            click(e) {
                if (current == 1) {
                    setMarker1(e.latlng); setCurrent(2);
                }
                else if (current == 2) {
                    setMarker2(e.latlng); setCurrent(1);
                }
            }
        })
    }

    return (
        <MapContainer center={position} zoom={5} style={{
            height: '100vh', width: '100wh'
        }}>
            <TileLayer
                url="https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
                attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
            />
            {marker1 && <Marker position={marker1}>
                <Popup>
                    The distance between two points is {marker2 ? (marker1.distanceTo(marker2) / 1000).toFixed(0) + " km" : " 0 km"}
                </Popup>
            </Marker>
            }
            {marker2 && <Marker position={marker2}>
                <Popup>
                    The distance between two points is {marker1 ? (marker1.distanceTo(marker2) / 1000).toFixed(0) + " km" : " 0 km"}
                </Popup>
            </Marker>
            }
            <LocationMarker></LocationMarker>
        </MapContainer >
    );
};

export default Map;